import { RateLimitedAxiosInstance } from 'axios-rate-limit';
/**
 * https://docs.api.wanikani.com/20170710/#rate-limit
 *
 * Requests per minute	60
 *
 * @param apiKey @default process.env['WANIKANI_API_KEY']
 * @returns
 */
export declare function makeWanikani(apiKey?: string): WaniKaniAxiosInstance;
export interface WaniKaniAxiosInstance extends RateLimitedAxiosInstance {
    kanji(params?: any): AsyncGenerator<{
        id: number;
        level: number;
        characters: string;
    }>;
    vocabulary(params?: any): AsyncGenerator<{
        id: number;
        level: number;
        characters: string;
        sentences: {
            ja: string;
            en: string;
        }[];
    }>;
    subjects<T = any>(params?: any): AsyncGenerator<{
        id: number;
        object: string;
        data_updated_at: string;
        url: string;
        data: T;
    }>;
    assignments(params?: any): AsyncGenerator<{
        id: number;
        srsLevel: number;
    }>;
}
export interface IResource<T = any> {
    id: number;
    url: string;
    data_updated_at: string;
    data: T;
}
export interface ICollection<T = any> {
    object: string;
    url: string;
    pages: {
        next_url?: string;
        previous_url?: string;
        per_page: number;
    };
    total_count: number;
    data_updated_at: string;
    data: T[];
}
export interface IError {
    error: string;
    code: number;
}
//# sourceMappingURL=index.d.ts.map